--
-- FMCdraw
-- this will add an new draw function to the mods that have all needed components.
--
-- author:    	Xentro (www.ls-uk.info)
-- @version:    v1.0
-- @date:       2012-09-09
-- @history:    v1.0 - inital implementation
-- 
--
FMCdraw = {};
FMCdraw.loaded = false;

addModEventListener(FMCdraw);

function FMCdraw:loadMap(name)
	if not FMCdraw.loaded then
		self.mDraw = {};
	end;
end;

function FMCdraw:deleteMap()
	self.mDraw = {};
end;

function FMCdraw:mouseEvent(posX, posY, isDown, isUp, button)
end;

function FMCdraw:keyEvent(unicode, sym, modifier, isDown)
end;

function FMCdraw:update(dt)
	for _, attachables in pairs(g_currentMission.attachables) do
		if attachables.allowNewDraw ~= nil then
			if self.mDraw[attachables] == nil then
				if attachables.addDraw ~= nil then
					local add = attachables:addDraw();
					if add ~= nil then
						self.mDraw[attachables] = true;
					end;
				end;
			else
				if attachables.deleteDraw ~= nil then
					local delete = attachables:deleteDraw();
					if delete ~= nil then
						self.mDraw[attachables] = nil;
					end;
				end;
			end;
		end;
	end;
end;

function FMCdraw:draw()
	for mDraw, _ in pairs(self.mDraw) do
		if mDraw.getVehicle ~= nil then
			local vehicle = mDraw:getVehicle();
			if vehicle ~= nil and vehicle:getIsActive() then
				if mDraw.FMCDraw ~= nil then
					mDraw:FMCDraw(mDraw, vehicle);
				end;
			end;
		end;
	end;
end;

FMCdraw.getAttachedTrailersFillLevelAndCapacity = function(self, oldFunc)
	local fillLevel = 0;
	local capacity = 0;
	local hasTrailer = false;
	
	if oldFunc ~= nil then
		fillLevel2, capacity2 = oldFunc(self);
		if fillLevel2 ~= nil and capacity2 ~= nil then
			fillLevel = fillLevel + fillLevel2;
			capacity = capacity + capacity2;
			hasTrailer = true;
		end;
	end;
	
	for mDraw, _ in pairs(FMCdraw.mDraw) do
		if mDraw.getVehicle ~= nil then
			local vehicle = mDraw:getVehicle();
			if vehicle ~= nil and self == vehicle then
				if mDraw.fillLevel ~= nil and mDraw.capacity ~= nil then
					fillLevel = fillLevel + mDraw.fillLevel;
					capacity = capacity + mDraw.capacity;
					hasTrailer = true;
				end;
			
				for k, implement in pairs(mDraw.attachedImplements) do
					local f, c = implement.object:getAttachedTrailersFillLevelAndCapacity();
					if f ~= nil and c ~= nil then
						fillLevel = fillLevel + f;
						capacity = capacity + c;
						hasTrailer = true;
					end;
				end;
			end;
		end;
	end;
	
	if hasTrailer then
		return fillLevel, capacity;
	end;
	return nil;
end;
Vehicle.getAttachedTrailersFillLevelAndCapacity = Utils.overwrittenFunction(Vehicle.getAttachedTrailersFillLevelAndCapacity, FMCdraw.getAttachedTrailersFillLevelAndCapacity);